<template>
  <div class="mod-config">
    <basic-container>
      <ttable
        :table="table"
        @handleSelectionChange="handleSelectionChange"
        :uploadInfo="uploadInfo"
        :options="options"
        :ajaxFun="ajaxFun"
        ref="LabelPrintElement"
      >
        <template #toolbar></template>
      </ttable>
      <!-- 弹窗, 新增 / 修改 -->
      <table-form
        v-if="addOrUpdateVisible"
        ref="addOrUpdate"
        @refreshDataList="getData"
      />
    </basic-container>
  </div>
</template>

<script>
import { fetchList, delObj } from '@/api/print/element'
import TableForm from './Form'
import { mapGetters } from 'vuex'
import ttable from '@/views/common/ztt-table.vue'

export default {
  data() {
    const tt = (prop, label, config) => {
      const w = (label.length - 1) * 20 + 15
      return Object.assign(
        {
          minWidth: w,
          // width: w < 140 ? 140 : w,
          prop,
          label,
          sort: true,
          isTrue: true,
          isSearch: true,
          searchInfoType: 'text'
        },
        config
      )
    }
    return {
      ajaxFun: fetchList,
      addOrUpdateVisible: false,
      multipleSelection: [],
      uploadInfo: {
        isShow: false
      },
      options: {
        height: 300, // 默认高度-为了表头固定
        stripe: true, // 是否为斑马纹 table
        highlightCurrentRow: false, // 是否要高亮当前行
        border: true, // 是否有纵向边框
        lazy: false, // 是否需要懒加载
        fit: true, // 列的宽度是否自撑开
        multiSelect: true, //
        seqNo: true,
        isRefresh: true, // 是否显示刷新按钮
        isShowHide: true, // 是否显示显影按钮
        isSearch: false, // 高级查询按钮
        defaultOrderBy: { column: 'itemCode', direction: 'desc' }
      },
      table: {
        total: 0,
        currentPage: 1,
        pageSize: 20,
        data: [],
        // 标题
        column: [
          tt('itemCode', '标签元素码', {
            render: { fun: this.addOrUpdateHandle }
          }),
          tt('itemDesc', '标签元素描述'),
          tt('createUser', '创建人'),
          tt('createTime', '创建时间'),
          tt('updateUser', '更新人'),
          tt('updateTime', '更新时间')
        ],
        toolbar: [
          {
            text: '新增',
            type: 'primary',
            fun: this.addOrUpdateHandle
          }
        ],
        operator: [
          {
            text: '删除',
            type: 'text',
            size: 'small',
            fun: this.deleteHandle
          }
        ],
        operatorConfig: {
          fixed: 'right',
          label: '操作',
          width: 100,
          minWidth: 100
        }
      }
    }
  },
  components: {
    TableForm,
    ttable
  },
  computed: {
    ...mapGetters(['permissions'])
  },
  created() {},
  methods: {
    // 获取数据列表
    getData() {
      this.$refs.LabelPrintElement.getDataList()
    },
    // 新增 / 修改
    addOrUpdateHandle(row) {
      this.addOrUpdateVisible = true
      this.$nextTick(() => {
        this.$refs.addOrUpdate.init(row)
      })
    },
    // 删除
    deleteHandle(row) {
      this.$confirm('是否确认删除标签元素码：' + row.itemCode, '提示', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        closeOnClickModal: false,
        type: 'warning'
      })
        .then(function() {
          return delObj(row.id)
        })
        .then((data) => {
          this.$message.success('删除成功')
          this.getData()
        })
    },
    handleSelectionChange(val) {
      this.multipleSelection = val
    }
  }
}
</script>
